# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codepipeline.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61ws/aws_codepipeline.proto\x12\x1coak9.tython.aws.codepipeline\x1a\x13shared/shared.proto\"\xc7\x01\n\'CustomActionTypeConfigurationProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\tqueryable\x18\x05 \x01(\x08\x12\x10\n\x08required\x18\x06 \x01(\x08\x12\x0e\n\x06secret\x18\x07 \x01(\x08\"\x88\x01\n\x1f\x43ustomActionTypeArtifactDetails\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rmaximum_count\x18\x02 \x01(\x05\x12\x15\n\rminimum_count\x18\x03 \x01(\x05\"\xd6\x01\n\x18\x43ustomActionTypeSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x65ntity_url_template\x18\x02 \x01(\t\x12\x1e\n\x16\x65xecution_url_template\x18\x03 \x01(\t\x12\x1d\n\x15revision_url_template\x18\x04 \x01(\t\x12%\n\x1dthird_party_configuration_url\x18\x05 \x01(\t\"\xe7\x04\n\x10\x43ustomActionType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12g\n\x18\x63onfiguration_properties\x18\x03 \x03(\x0b\x32\x45.oak9.tython.aws.codepipeline.CustomActionTypeConfigurationProperties\x12]\n\x16input_artifact_details\x18\x04 \x01(\x0b\x32=.oak9.tython.aws.codepipeline.CustomActionTypeArtifactDetails\x12^\n\x17output_artifact_details\x18\x05 \x01(\x0b\x32=.oak9.tython.aws.codepipeline.CustomActionTypeArtifactDetails\x12\x10\n\x08provider\x18\x06 \x01(\t\x12H\n\x08settings\x18\x07 \x01(\x0b\x32\x36.oak9.tython.aws.codepipeline.CustomActionTypeSettings\x12\x46\n\x04tags\x18\x08 \x03(\x0b\x32\x38.oak9.tython.aws.codepipeline.CustomActionType.TagsEntry\x12\x0f\n\x07version\x18\t \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcc\x01\n\x0c\x43odePipeline\x12J\n\x12\x63ustom_action_type\x18\x01 \x03(\x0b\x32..oak9.tython.aws.codepipeline.CustomActionType\x12\x38\n\x08pipeline\x18\x02 \x03(\x0b\x32&.oak9.tython.aws.codepipeline.Pipeline\x12\x36\n\x07webhook\x18\x03 \x03(\x0b\x32%.oak9.tython.aws.codepipeline.Webhook\"\\\n\x15PipelineEncryptionKey\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\"\xaf\x01\n\x15PipelineArtifactStore\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x0e\x65ncryption_key\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.codepipeline.PipelineEncryptionKey\x12\x10\n\x08location\x18\x03 \x01(\t\"\xb0\x01\n\x18PipelineArtifactStoreMap\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x0e\x61rtifact_store\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.codepipeline.PipelineArtifactStore\x12\x0e\n\x06region\x18\x03 \x01(\t\"v\n\x17PipelineStageTransition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x12\n\nstage_name\x18\x03 \x01(\t\"\x93\x01\n\x14PipelineActionTypeId\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\"^\n\x15PipelineInputArtifact\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"_\n\x16PipelineOutputArtifact\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xad\x04\n\x19PipelineActionDeclaration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\x0e\x61\x63tion_type_id\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.codepipeline.PipelineActionTypeId\x12\x61\n\rconfiguration\x18\x03 \x03(\x0b\x32J.oak9.tython.aws.codepipeline.PipelineActionDeclaration.ConfigurationEntry\x12L\n\x0finput_artifacts\x18\x04 \x03(\x0b\x32\x33.oak9.tython.aws.codepipeline.PipelineInputArtifact\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x11\n\tnamespace\x18\x06 \x01(\t\x12N\n\x10output_artifacts\x18\x07 \x03(\x0b\x32\x34.oak9.tython.aws.codepipeline.PipelineOutputArtifact\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x10\n\x08role_arn\x18\t \x01(\t\x12\x11\n\trun_order\x18\n \x01(\x05\x1a\x34\n\x12\x43onfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"c\n\x1aPipelineBlockerDeclaration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xf7\x01\n\x18PipelineStageDeclaration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12H\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32\x37.oak9.tython.aws.codepipeline.PipelineActionDeclaration\x12J\n\x08\x62lockers\x18\x03 \x03(\x0b\x32\x38.oak9.tython.aws.codepipeline.PipelineBlockerDeclaration\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xbd\x04\n\x08Pipeline\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x0e\x61rtifact_store\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.codepipeline.PipelineArtifactStore\x12O\n\x0f\x61rtifact_stores\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.codepipeline.PipelineArtifactStoreMap\x12`\n!disable_inbound_stage_transitions\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.codepipeline.PipelineStageTransition\x12\x0c\n\x04name\x18\x05 \x01(\t\x12#\n\x1brestart_execution_on_update\x18\x06 \x01(\x08\x12\x10\n\x08role_arn\x18\x07 \x01(\t\x12\x46\n\x06stages\x18\x08 \x03(\x0b\x32\x36.oak9.tython.aws.codepipeline.PipelineStageDeclaration\x12>\n\x04tags\x18\t \x03(\x0b\x32\x30.oak9.tython.aws.codepipeline.Pipeline.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8a\x01\n\x1fWebhookWebhookAuthConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61llowed_ip_range\x18\x02 \x01(\t\x12\x14\n\x0csecret_token\x18\x03 \x01(\t\"|\n\x18WebhookWebhookFilterRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tjson_path\x18\x02 \x01(\t\x12\x14\n\x0cmatch_equals\x18\x03 \x01(\t\"\x8a\x03\n\x07Webhook\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n\x1c\x61uthentication_configuration\x18\x02 \x01(\x0b\x32=.oak9.tython.aws.codepipeline.WebhookWebhookAuthConfiguration\x12G\n\x07\x66ilters\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.codepipeline.WebhookWebhookFilterRule\x12\x16\n\x0e\x61uthentication\x18\x04 \x01(\t\x12\x17\n\x0ftarget_pipeline\x18\x05 \x01(\t\x12\x15\n\rtarget_action\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x1f\n\x17target_pipeline_version\x18\x08 \x01(\x05\x12!\n\x19register_with_third_party\x18\t \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codepipeline_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CUSTOMACTIONTYPE_TAGSENTRY._options = None
  _CUSTOMACTIONTYPE_TAGSENTRY._serialized_options = b'8\001'
  _PIPELINEACTIONDECLARATION_CONFIGURATIONENTRY._options = None
  _PIPELINEACTIONDECLARATION_CONFIGURATIONENTRY._serialized_options = b'8\001'
  _PIPELINE_TAGSENTRY._options = None
  _PIPELINE_TAGSENTRY._serialized_options = b'8\001'
  _CUSTOMACTIONTYPECONFIGURATIONPROPERTIES._serialized_start=82
  _CUSTOMACTIONTYPECONFIGURATIONPROPERTIES._serialized_end=281
  _CUSTOMACTIONTYPEARTIFACTDETAILS._serialized_start=284
  _CUSTOMACTIONTYPEARTIFACTDETAILS._serialized_end=420
  _CUSTOMACTIONTYPESETTINGS._serialized_start=423
  _CUSTOMACTIONTYPESETTINGS._serialized_end=637
  _CUSTOMACTIONTYPE._serialized_start=640
  _CUSTOMACTIONTYPE._serialized_end=1255
  _CUSTOMACTIONTYPE_TAGSENTRY._serialized_start=1212
  _CUSTOMACTIONTYPE_TAGSENTRY._serialized_end=1255
  _CODEPIPELINE._serialized_start=1258
  _CODEPIPELINE._serialized_end=1462
  _PIPELINEENCRYPTIONKEY._serialized_start=1464
  _PIPELINEENCRYPTIONKEY._serialized_end=1556
  _PIPELINEARTIFACTSTORE._serialized_start=1559
  _PIPELINEARTIFACTSTORE._serialized_end=1734
  _PIPELINEARTIFACTSTOREMAP._serialized_start=1737
  _PIPELINEARTIFACTSTOREMAP._serialized_end=1913
  _PIPELINESTAGETRANSITION._serialized_start=1915
  _PIPELINESTAGETRANSITION._serialized_end=2033
  _PIPELINEACTIONTYPEID._serialized_start=2036
  _PIPELINEACTIONTYPEID._serialized_end=2183
  _PIPELINEINPUTARTIFACT._serialized_start=2185
  _PIPELINEINPUTARTIFACT._serialized_end=2279
  _PIPELINEOUTPUTARTIFACT._serialized_start=2281
  _PIPELINEOUTPUTARTIFACT._serialized_end=2376
  _PIPELINEACTIONDECLARATION._serialized_start=2379
  _PIPELINEACTIONDECLARATION._serialized_end=2936
  _PIPELINEACTIONDECLARATION_CONFIGURATIONENTRY._serialized_start=2884
  _PIPELINEACTIONDECLARATION_CONFIGURATIONENTRY._serialized_end=2936
  _PIPELINEBLOCKERDECLARATION._serialized_start=2938
  _PIPELINEBLOCKERDECLARATION._serialized_end=3037
  _PIPELINESTAGEDECLARATION._serialized_start=3040
  _PIPELINESTAGEDECLARATION._serialized_end=3287
  _PIPELINE._serialized_start=3290
  _PIPELINE._serialized_end=3863
  _PIPELINE_TAGSENTRY._serialized_start=1212
  _PIPELINE_TAGSENTRY._serialized_end=1255
  _WEBHOOKWEBHOOKAUTHCONFIGURATION._serialized_start=3866
  _WEBHOOKWEBHOOKAUTHCONFIGURATION._serialized_end=4004
  _WEBHOOKWEBHOOKFILTERRULE._serialized_start=4006
  _WEBHOOKWEBHOOKFILTERRULE._serialized_end=4130
  _WEBHOOK._serialized_start=4133
  _WEBHOOK._serialized_end=4527
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Alias(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALIAS_NAME_FIELD_NUMBER: builtins.int
    TARGET_KEY_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    alias_name: builtins.str
    target_key_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alias_name: builtins.str = ...,
        target_key_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alias_name", b"alias_name", "resource_info", b"resource_info", "target_key_id", b"target_key_id"]) -> None: ...

global___Alias = Alias

@typing_extensions.final
class KMS(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALIAS_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    CUSTOM_KEY_STORE_FIELD_NUMBER: builtins.int
    GRANT_FIELD_NUMBER: builtins.int
    @property
    def alias(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Alias]: ...
    @property
    def key(self) -> global___Key: ...
    @property
    def custom_key_store(self) -> global___CustomKeyStore: ...
    @property
    def grant(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Grant]: ...
    def __init__(
        self,
        *,
        alias: collections.abc.Iterable[global___Alias] | None = ...,
        key: global___Key | None = ...,
        custom_key_store: global___CustomKeyStore | None = ...,
        grant: collections.abc.Iterable[global___Grant] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_key_store", b"custom_key_store", "key", b"key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alias", b"alias", "custom_key_store", b"custom_key_store", "grant", b"grant", "key", b"key"]) -> None: ...

global___KMS = KMS

@typing_extensions.final
class CustomKeyStore(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_HSM_CLUSTER_ID_FIELD_NUMBER: builtins.int
    CUSTOM_KEY_STORE_NAME_FIELD_NUMBER: builtins.int
    KEY_STORE_PASSWORD_FIELD_NUMBER: builtins.int
    TRUST_ANCHOR_CERTIFICATE_FIELD_NUMBER: builtins.int
    cloud_hsm_cluster_id: builtins.str
    custom_key_store_name: builtins.str
    key_store_password: builtins.str
    trust_anchor_certificate: builtins.str
    def __init__(
        self,
        *,
        cloud_hsm_cluster_id: builtins.str = ...,
        custom_key_store_name: builtins.str = ...,
        key_store_password: builtins.str = ...,
        trust_anchor_certificate: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_hsm_cluster_id", b"cloud_hsm_cluster_id", "custom_key_store_name", b"custom_key_store_name", "key_store_password", b"key_store_password", "trust_anchor_certificate", b"trust_anchor_certificate"]) -> None: ...

global___CustomKeyStore = CustomKeyStore

@typing_extensions.final
class Grant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConstraintsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    GRANTEE_PRINCIPAL_FIELD_NUMBER: builtins.int
    RETIRING_PRINCIPAL_FIELD_NUMBER: builtins.int
    GRANT_TOKENS_FIELD_NUMBER: builtins.int
    KEY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    CONSTRAINTS_FIELD_NUMBER: builtins.int
    grantee_principal: builtins.str
    retiring_principal: builtins.str
    @property
    def grant_tokens(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key_id: builtins.str
    name: builtins.str
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def constraints(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        grantee_principal: builtins.str = ...,
        retiring_principal: builtins.str = ...,
        grant_tokens: collections.abc.Iterable[builtins.str] | None = ...,
        key_id: builtins.str = ...,
        name: builtins.str = ...,
        operations: collections.abc.Iterable[builtins.str] | None = ...,
        constraints: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["constraints", b"constraints", "grant_tokens", b"grant_tokens", "grantee_principal", b"grantee_principal", "key_id", b"key_id", "name", b"name", "operations", b"operations", "retiring_principal", b"retiring_principal"]) -> None: ...

global___Grant = Grant

@typing_extensions.final
class Key(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ENABLE_KEY_ROTATION_FIELD_NUMBER: builtins.int
    KEY_USAGE_FIELD_NUMBER: builtins.int
    PENDING_WINDOW_IN_DAYS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CUSTOM_KEY_STORE_ID_FIELD_NUMBER: builtins.int
    BYPASS_POLICY_LOCKOUT_SAFETY_CHECK_FIELD_NUMBER: builtins.int
    KEY_SPEC_FIELD_NUMBER: builtins.int
    MULTI_REGION_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    KEY_POLICY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    enabled: builtins.bool
    enable_key_rotation: builtins.bool
    key_usage: builtins.str
    pending_window_in_days: builtins.int
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    custom_key_store_id: builtins.str
    bypass_policy_lockout_safety_check: builtins.bool
    key_spec: builtins.str
    multi_region: builtins.bool
    origin: builtins.str
    key_policy: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        enabled: builtins.bool = ...,
        enable_key_rotation: builtins.bool = ...,
        key_usage: builtins.str = ...,
        pending_window_in_days: builtins.int = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        custom_key_store_id: builtins.str = ...,
        bypass_policy_lockout_safety_check: builtins.bool = ...,
        key_spec: builtins.str = ...,
        multi_region: builtins.bool = ...,
        origin: builtins.str = ...,
        key_policy: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bypass_policy_lockout_safety_check", b"bypass_policy_lockout_safety_check", "custom_key_store_id", b"custom_key_store_id", "description", b"description", "enable_key_rotation", b"enable_key_rotation", "enabled", b"enabled", "key_policy", b"key_policy", "key_spec", b"key_spec", "key_usage", b"key_usage", "multi_region", b"multi_region", "origin", b"origin", "pending_window_in_days", b"pending_window_in_days", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Key = Key



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Accelerator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IP_ADDRESS_TYPE_FIELD_NUMBER: builtins.int
    IP_ADDRESSES_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    ip_address_type: builtins.str
    @property
    def ip_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enabled: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        ip_address_type: builtins.str = ...,
        ip_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        enabled: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "ip_address_type", b"ip_address_type", "ip_addresses", b"ip_addresses", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Accelerator = Accelerator

@typing_extensions.final
class GlobalAccelerator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCELERATOR_FIELD_NUMBER: builtins.int
    ENDPOINT_GROUP_FIELD_NUMBER: builtins.int
    LISTENER_FIELD_NUMBER: builtins.int
    @property
    def accelerator(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Accelerator]: ...
    @property
    def endpoint_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointGroup]: ...
    @property
    def listener(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Listener]: ...
    def __init__(
        self,
        *,
        accelerator: collections.abc.Iterable[global___Accelerator] | None = ...,
        endpoint_group: collections.abc.Iterable[global___EndpointGroup] | None = ...,
        listener: collections.abc.Iterable[global___Listener] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator", b"accelerator", "endpoint_group", b"endpoint_group", "listener", b"listener"]) -> None: ...

global___GlobalAccelerator = GlobalAccelerator

@typing_extensions.final
class EndpointGroupEndpointConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENDPOINT_ID_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    CLIENT_IP_PRESERVATION_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    endpoint_id: builtins.str
    weight: builtins.int
    client_ip_preservation_enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        endpoint_id: builtins.str = ...,
        weight: builtins.int = ...,
        client_ip_preservation_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_ip_preservation_enabled", b"client_ip_preservation_enabled", "endpoint_id", b"endpoint_id", "resource_info", b"resource_info", "weight", b"weight"]) -> None: ...

global___EndpointGroupEndpointConfiguration = EndpointGroupEndpointConfiguration

@typing_extensions.final
class EndpointGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LISTENER_ARN_FIELD_NUMBER: builtins.int
    ENDPOINT_GROUP_REGION_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    TRAFFIC_DIAL_PERCENTAGE_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_PORT_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_PROTOCOL_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_PATH_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_INTERVAL_SECONDS_FIELD_NUMBER: builtins.int
    THRESHOLD_COUNT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    listener_arn: builtins.str
    endpoint_group_region: builtins.str
    @property
    def endpoint_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EndpointGroupEndpointConfiguration]: ...
    traffic_dial_percentage: builtins.float
    health_check_port: builtins.int
    health_check_protocol: builtins.str
    health_check_path: builtins.str
    health_check_interval_seconds: builtins.int
    threshold_count: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        listener_arn: builtins.str = ...,
        endpoint_group_region: builtins.str = ...,
        endpoint_configurations: collections.abc.Iterable[global___EndpointGroupEndpointConfiguration] | None = ...,
        traffic_dial_percentage: builtins.float = ...,
        health_check_port: builtins.int = ...,
        health_check_protocol: builtins.str = ...,
        health_check_path: builtins.str = ...,
        health_check_interval_seconds: builtins.int = ...,
        threshold_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_configurations", b"endpoint_configurations", "endpoint_group_region", b"endpoint_group_region", "health_check_interval_seconds", b"health_check_interval_seconds", "health_check_path", b"health_check_path", "health_check_port", b"health_check_port", "health_check_protocol", b"health_check_protocol", "listener_arn", b"listener_arn", "resource_info", b"resource_info", "threshold_count", b"threshold_count", "traffic_dial_percentage", b"traffic_dial_percentage"]) -> None: ...

global___EndpointGroup = EndpointGroup

@typing_extensions.final
class ListenerPortRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FROM_PORT_FIELD_NUMBER: builtins.int
    TO_PORT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    from_port: builtins.int
    to_port: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        from_port: builtins.int = ...,
        to_port: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_port", b"from_port", "resource_info", b"resource_info", "to_port", b"to_port"]) -> None: ...

global___ListenerPortRange = ListenerPortRange

@typing_extensions.final
class Listener(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCELERATOR_ARN_FIELD_NUMBER: builtins.int
    PORT_RANGES_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    CLIENT_AFFINITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    accelerator_arn: builtins.str
    @property
    def port_ranges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerPortRange]: ...
    protocol: builtins.str
    client_affinity: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        accelerator_arn: builtins.str = ...,
        port_ranges: collections.abc.Iterable[global___ListenerPortRange] | None = ...,
        protocol: builtins.str = ...,
        client_affinity: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_arn", b"accelerator_arn", "client_affinity", b"client_affinity", "port_ranges", b"port_ranges", "protocol", b"protocol", "resource_info", b"resource_info"]) -> None: ...

global___Listener = Listener



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_synthetics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_synthetics.proto\x12\x1aoak9.tython.aws.synthetics\x1a\x13shared/shared.proto\"\xa4\x01\n\nCanaryCode\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\ts3_bucket\x18\x02 \x01(\t\x12\x0e\n\x06s3_key\x18\x03 \x01(\t\x12\x19\n\x11s3_object_version\x18\x04 \x01(\t\x12\x0e\n\x06script\x18\x05 \x01(\t\x12\x0f\n\x07handler\x18\x06 \x01(\t\"z\n\x0e\x43\x61narySchedule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x1b\n\x13\x64uration_in_seconds\x18\x03 \x01(\t\"\x8a\x01\n\x0f\x43\x61naryVPCConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06vpc_id\x18\x02 \x01(\t\x12\x12\n\nsubnet_ids\x18\x03 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x04 \x03(\t\"|\n\x0f\x43\x61naryRunConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12timeout_in_seconds\x18\x02 \x01(\x05\x12\x14\n\x0cmemory_in_mb\x18\x03 \x01(\x05\"\xea\x04\n\x06\x43\x61nary\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x34\n\x04\x63ode\x18\x03 \x01(\x0b\x32&.oak9.tython.aws.synthetics.CanaryCode\x12\x1c\n\x14\x61rtifact_s3_location\x18\x04 \x01(\t\x12<\n\x08schedule\x18\x05 \x01(\x0b\x32*.oak9.tython.aws.synthetics.CanarySchedule\x12\x1a\n\x12\x65xecution_role_arn\x18\x06 \x01(\t\x12\x17\n\x0fruntime_version\x18\x07 \x01(\t\x12 \n\x18success_retention_period\x18\x08 \x01(\x05\x12 \n\x18\x66\x61ilure_retention_period\x18\t \x01(\x05\x12:\n\x04tags\x18\n \x03(\x0b\x32,.oak9.tython.aws.synthetics.Canary.TagsEntry\x12?\n\nvpc_config\x18\x0b \x01(\x0b\x32+.oak9.tython.aws.synthetics.CanaryVPCConfig\x12?\n\nrun_config\x18\x0c \x01(\x0b\x32+.oak9.tython.aws.synthetics.CanaryRunConfig\x12#\n\x1bstart_canary_after_creation\x18\r \x01(\x08\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\nSynthetics\x12\x32\n\x06\x63\x61nary\x18\x01 \x03(\x0b\x32\".oak9.tython.aws.synthetics.Canaryb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_synthetics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CANARY_TAGSENTRY._options = None
  _CANARY_TAGSENTRY._serialized_options = b'8\001'
  _CANARYCODE._serialized_start=78
  _CANARYCODE._serialized_end=242
  _CANARYSCHEDULE._serialized_start=244
  _CANARYSCHEDULE._serialized_end=366
  _CANARYVPCCONFIG._serialized_start=369
  _CANARYVPCCONFIG._serialized_end=507
  _CANARYRUNCONFIG._serialized_start=509
  _CANARYRUNCONFIG._serialized_end=633
  _CANARY._serialized_start=636
  _CANARY._serialized_end=1254
  _CANARY_TAGSENTRY._serialized_start=1211
  _CANARY_TAGSENTRY._serialized_end=1254
  _SYNTHETICS._serialized_start=1256
  _SYNTHETICS._serialized_end=1320
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DataCatalogTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DataCatalogTags = DataCatalogTags

@typing_extensions.final
class DataCatalog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> global___DataCatalogTags: ...
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: global___DataCatalogTags | None = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tags", b"tags"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "parameters", b"parameters", "resource_info", b"resource_info", "tags", b"tags", "type", b"type"]) -> None: ...

global___DataCatalog = DataCatalog

@typing_extensions.final
class Athena(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_CATALOG_FIELD_NUMBER: builtins.int
    NAMED_QUERY_FIELD_NUMBER: builtins.int
    WORK_GROUP_FIELD_NUMBER: builtins.int
    @property
    def data_catalog(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataCatalog]: ...
    @property
    def named_query(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamedQuery]: ...
    @property
    def work_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkGroup]: ...
    def __init__(
        self,
        *,
        data_catalog: collections.abc.Iterable[global___DataCatalog] | None = ...,
        named_query: collections.abc.Iterable[global___NamedQuery] | None = ...,
        work_group: collections.abc.Iterable[global___WorkGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_catalog", b"data_catalog", "named_query", b"named_query", "work_group", b"work_group"]) -> None: ...

global___Athena = Athena

@typing_extensions.final
class NamedQuery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    QUERY_STRING_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    database: builtins.str
    description: builtins.str
    query_string: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        database: builtins.str = ...,
        description: builtins.str = ...,
        query_string: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database", b"database", "description", b"description", "name", b"name", "query_string", b"query_string", "resource_info", b"resource_info"]) -> None: ...

global___NamedQuery = NamedQuery

@typing_extensions.final
class WorkGroupTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___WorkGroupTags = WorkGroupTags

@typing_extensions.final
class WorkGroupEncryptionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENCRYPTION_OPTION_FIELD_NUMBER: builtins.int
    KMS_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    encryption_option: builtins.str
    kms_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        encryption_option: builtins.str = ...,
        kms_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption_option", b"encryption_option", "kms_key", b"kms_key", "resource_info", b"resource_info"]) -> None: ...

global___WorkGroupEncryptionConfiguration = WorkGroupEncryptionConfiguration

@typing_extensions.final
class WorkGroupResultConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    OUTPUT_LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def encryption_configuration(self) -> global___WorkGroupEncryptionConfiguration: ...
    output_location: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        encryption_configuration: global___WorkGroupEncryptionConfiguration | None = ...,
        output_location: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryption_configuration", b"encryption_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption_configuration", b"encryption_configuration", "output_location", b"output_location", "resource_info", b"resource_info"]) -> None: ...

global___WorkGroupResultConfiguration = WorkGroupResultConfiguration

@typing_extensions.final
class WorkGroupWorkGroupConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BYTES_SCANNED_CUTOFF_PER_QUERY_FIELD_NUMBER: builtins.int
    ENFORCE_WORK_GROUP_CONFIGURATION_FIELD_NUMBER: builtins.int
    PUBLISH_CLOUD_WATCH_METRICS_ENABLED_FIELD_NUMBER: builtins.int
    REQUESTER_PAYS_ENABLED_FIELD_NUMBER: builtins.int
    RESULT_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bytes_scanned_cutoff_per_query: builtins.int
    enforce_work_group_configuration: builtins.bool
    publish_cloud_watch_metrics_enabled: builtins.bool
    requester_pays_enabled: builtins.bool
    @property
    def result_configuration(self) -> global___WorkGroupResultConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bytes_scanned_cutoff_per_query: builtins.int = ...,
        enforce_work_group_configuration: builtins.bool = ...,
        publish_cloud_watch_metrics_enabled: builtins.bool = ...,
        requester_pays_enabled: builtins.bool = ...,
        result_configuration: global___WorkGroupResultConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "result_configuration", b"result_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bytes_scanned_cutoff_per_query", b"bytes_scanned_cutoff_per_query", "enforce_work_group_configuration", b"enforce_work_group_configuration", "publish_cloud_watch_metrics_enabled", b"publish_cloud_watch_metrics_enabled", "requester_pays_enabled", b"requester_pays_enabled", "resource_info", b"resource_info", "result_configuration", b"result_configuration"]) -> None: ...

global___WorkGroupWorkGroupConfiguration = WorkGroupWorkGroupConfiguration

@typing_extensions.final
class WorkGroupResultConfigurationUpdates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    OUTPUT_LOCATION_FIELD_NUMBER: builtins.int
    REMOVE_ENCRYPTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    REMOVE_OUTPUT_LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def encryption_configuration(self) -> global___WorkGroupEncryptionConfiguration: ...
    output_location: builtins.str
    remove_encryption_configuration: builtins.bool
    remove_output_location: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        encryption_configuration: global___WorkGroupEncryptionConfiguration | None = ...,
        output_location: builtins.str = ...,
        remove_encryption_configuration: builtins.bool = ...,
        remove_output_location: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryption_configuration", b"encryption_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption_configuration", b"encryption_configuration", "output_location", b"output_location", "remove_encryption_configuration", b"remove_encryption_configuration", "remove_output_location", b"remove_output_location", "resource_info", b"resource_info"]) -> None: ...

global___WorkGroupResultConfigurationUpdates = WorkGroupResultConfigurationUpdates

@typing_extensions.final
class WorkGroupWorkGroupConfigurationUpdates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BYTES_SCANNED_CUTOFF_PER_QUERY_FIELD_NUMBER: builtins.int
    ENFORCE_WORK_GROUP_CONFIGURATION_FIELD_NUMBER: builtins.int
    PUBLISH_CLOUD_WATCH_METRICS_ENABLED_FIELD_NUMBER: builtins.int
    REQUESTER_PAYS_ENABLED_FIELD_NUMBER: builtins.int
    RESULT_CONFIGURATION_UPDATES_FIELD_NUMBER: builtins.int
    REMOVE_BYTES_SCANNED_CUTOFF_PER_QUERY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bytes_scanned_cutoff_per_query: builtins.int
    enforce_work_group_configuration: builtins.bool
    publish_cloud_watch_metrics_enabled: builtins.bool
    requester_pays_enabled: builtins.bool
    @property
    def result_configuration_updates(self) -> global___WorkGroupResultConfigurationUpdates: ...
    remove_bytes_scanned_cutoff_per_query: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bytes_scanned_cutoff_per_query: builtins.int = ...,
        enforce_work_group_configuration: builtins.bool = ...,
        publish_cloud_watch_metrics_enabled: builtins.bool = ...,
        requester_pays_enabled: builtins.bool = ...,
        result_configuration_updates: global___WorkGroupResultConfigurationUpdates | None = ...,
        remove_bytes_scanned_cutoff_per_query: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "result_configuration_updates", b"result_configuration_updates"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bytes_scanned_cutoff_per_query", b"bytes_scanned_cutoff_per_query", "enforce_work_group_configuration", b"enforce_work_group_configuration", "publish_cloud_watch_metrics_enabled", b"publish_cloud_watch_metrics_enabled", "remove_bytes_scanned_cutoff_per_query", b"remove_bytes_scanned_cutoff_per_query", "requester_pays_enabled", b"requester_pays_enabled", "resource_info", b"resource_info", "result_configuration_updates", b"result_configuration_updates"]) -> None: ...

global___WorkGroupWorkGroupConfigurationUpdates = WorkGroupWorkGroupConfigurationUpdates

@typing_extensions.final
class WorkGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    WORK_GROUP_CONFIGURATION_FIELD_NUMBER: builtins.int
    WORK_GROUP_CONFIGURATION_UPDATES_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    RECURSIVE_DELETE_OPTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    @property
    def tags(self) -> global___WorkGroupTags: ...
    @property
    def work_group_configuration(self) -> global___WorkGroupWorkGroupConfiguration: ...
    @property
    def work_group_configuration_updates(self) -> global___WorkGroupWorkGroupConfigurationUpdates: ...
    state: builtins.str
    recursive_delete_option: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        tags: global___WorkGroupTags | None = ...,
        work_group_configuration: global___WorkGroupWorkGroupConfiguration | None = ...,
        work_group_configuration_updates: global___WorkGroupWorkGroupConfigurationUpdates | None = ...,
        state: builtins.str = ...,
        recursive_delete_option: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tags", b"tags", "work_group_configuration", b"work_group_configuration", "work_group_configuration_updates", b"work_group_configuration_updates"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "recursive_delete_option", b"recursive_delete_option", "resource_info", b"resource_info", "state", b"state", "tags", b"tags", "work_group_configuration", b"work_group_configuration", "work_group_configuration_updates", b"work_group_configuration_updates"]) -> None: ...

global___WorkGroup = WorkGroup
